import type { PropType, ExtractPropTypes } from 'vue';
import type { DataNode, EventDataNode, Key } from '../vc-tree/interface';
import type { TreeNodeProps } from '../vc-tree/props';
export interface AntdTreeNodeAttribute {
    eventKey: string;
    prefixCls: string;
    class: string;
    expanded: boolean;
    selected: boolean;
    checked: boolean;
    halfChecked: boolean;
    children: any;
    title: any;
    pos: string;
    dragOver: boolean;
    dragOverGapTop: boolean;
    dragOverGapBottom: boolean;
    isLeaf: boolean;
    selectable: boolean;
    disabled: boolean;
    disableCheckbox: boolean;
}
export declare type AntTreeNodeProps = TreeNodeProps;
export declare type TreeDataItem = DataNode;
export interface AntTreeNodeBaseEvent {
    node: EventDataNode;
    nativeEvent: MouseEvent;
}
export interface AntTreeNodeCheckedEvent extends AntTreeNodeBaseEvent {
    event: 'check';
    checked?: boolean;
    checkedNodes?: DataNode[];
}
export interface AntTreeNodeSelectedEvent extends AntTreeNodeBaseEvent {
    event: 'select';
    selected?: boolean;
    selectedNodes?: DataNode[];
}
export interface AntTreeNodeExpandedEvent extends AntTreeNodeBaseEvent {
    expanded?: boolean;
}
export interface AntTreeNodeMouseEvent {
    node: EventDataNode;
    event: DragEvent;
}
export interface AntTreeNodeDragEnterEvent extends AntTreeNodeMouseEvent {
    expandedKeys: Key[];
}
export interface AntTreeNodeDropEvent {
    node: EventDataNode;
    dragNode: EventDataNode;
    dragNodesKeys: Key[];
    dropPosition: number;
    dropToGap?: boolean;
    event: MouseEvent;
}
export declare const treeProps: () => {
    showLine: {
        type: BooleanConstructor;
        default: any;
    };
    /** 是否支持多选 */
    multiple: {
        type: BooleanConstructor;
        default: any;
    };
    /** 是否自动展开父节点 */
    autoExpandParent: {
        type: BooleanConstructor;
        default: any;
    };
    /** checkable状态下节点选择完全受控（父子节点选中状态不再关联）*/
    checkStrictly: {
        type: BooleanConstructor;
        default: any;
    };
    /** 是否支持选中 */
    checkable: {
        type: BooleanConstructor;
        default: any;
    };
    /** 是否禁用树 */
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    /** 默认展开所有树节点 */
    defaultExpandAll: {
        type: BooleanConstructor;
        default: any;
    };
    /** 默认展开对应树节点 */
    defaultExpandParent: {
        type: BooleanConstructor;
        default: any;
    };
    /** 默认展开指定的树节点 */
    defaultExpandedKeys: {
        type: PropType<any[]>;
    };
    /** （受控）展开指定的树节点 */
    expandedKeys: {
        type: PropType<any[]>;
    };
    /** （受控）选中复选框的树节点 */
    checkedKeys: {
        type: PropType<any[] | {
            checked: Key[];
            halfChecked: Key[];
        }>;
    };
    /** 默认选中复选框的树节点 */
    defaultCheckedKeys: {
        type: PropType<any[]>;
    };
    /** （受控）设置选中的树节点 */
    selectedKeys: {
        type: PropType<any[]>;
    };
    /** 默认选中的树节点 */
    defaultSelectedKeys: {
        type: PropType<any[]>;
    };
    selectable: {
        type: BooleanConstructor;
        default: any;
    };
    loadedKeys: {
        type: PropType<any[]>;
    };
    draggable: {
        type: BooleanConstructor;
        default: any;
    };
    showIcon: {
        type: BooleanConstructor;
        default: any;
    };
    icon: {
        type: PropType<(nodeProps: AntdTreeNodeAttribute) => any>;
    };
    switcherIcon: import("vue-types").VueTypeValidableDef<any>;
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    /**
     * @default{title,key,children}
     * deprecated, please use `fieldNames` instead
     * 替换treeNode中 title,key,children字段为treeData中对应的字段
     */
    replaceFields: {
        type: PropType<any>;
    };
    blockNode: {
        type: BooleanConstructor;
        default: any;
    };
    openAnimation: import("vue-types").VueTypeValidableDef<any>;
    focusable: {
        type: BooleanConstructor;
        default: any;
    };
    tabindex: NumberConstructor;
    children: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    treeData: {
        type: PropType<any[]>;
    };
    fieldNames: {
        type: PropType<any>;
    };
    allowDrop: {
        type: PropType<import("../vc-tree/props").AllowDrop>;
    };
    dropIndicatorRender: {
        type: PropType<(props: {
            dropPosition: 0 | 1 | -1;
            dropLevelOffset: number;
            indent: number;
            prefixCls: string;
            direction: any;
        }) => any>;
    };
    onFocus: {
        type: PropType<(e: FocusEvent) => void>;
    };
    onBlur: {
        type: PropType<(e: FocusEvent) => void>;
    };
    onKeydown: {
        type: PropType<import("../_util/EventInterface").EventHandler>;
    };
    onContextmenu: {
        type: PropType<import("../_util/EventInterface").EventHandler>;
    };
    onClick: {
        type: PropType<import("../vc-tree/contextTypes").NodeMouseEventHandler>;
    };
    onDblclick: {
        type: PropType<import("../vc-tree/contextTypes").NodeMouseEventHandler>;
    };
    onScroll: {
        type: PropType<import("../_util/EventInterface").EventHandler>;
    };
    onExpand: {
        type: PropType<(expandedKeys: any[], info: {
            node: any;
            expanded: boolean;
            nativeEvent: MouseEvent;
        }) => void>;
    };
    onCheck: {
        type: PropType<(checked: any[] | {
            checked: any[];
            halfChecked: any[];
        }, info: import("../vc-tree/props").CheckInfo) => void>;
    };
    onSelect: {
        type: PropType<(selectedKeys: any[], info: {
            event: "select";
            selected: boolean;
            node: any;
            selectedNodes: any[];
            nativeEvent: MouseEvent;
        }) => void>;
    };
    onLoad: {
        type: PropType<(loadedKeys: any[], info: {
            event: "load";
            node: any;
        }) => void>;
    };
    loadData: {
        type: PropType<(treeNode: any) => Promise<void>>;
    };
    onMouseenter: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeMouseEventParams) => void>;
    };
    onMouseleave: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeMouseEventParams) => void>;
    };
    onRightClick: {
        type: PropType<(info: {
            event: MouseEvent;
            node: any;
        }) => void>;
    };
    onDragstart: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeDragEventParams) => void>;
    };
    onDragenter: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeDragEventParams & {
            expandedKeys: any[];
        }) => void>;
    };
    onDragover: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeDragEventParams) => void>;
    };
    onDragleave: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeDragEventParams) => void>;
    };
    onDragend: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeDragEventParams) => void>;
    };
    onDrop: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeDragEventParams & {
            dragNode: any;
            dragNodesKeys: any[];
            dropPosition: number;
            dropToGap: boolean;
        }) => void>;
    };
    onActiveChange: {
        type: PropType<(key: any) => void>;
    };
    filterTreeNode: {
        type: PropType<(treeNode: any) => boolean>;
    };
    motion: import("vue-types").VueTypeValidableDef<any>;
    height: NumberConstructor;
    itemHeight: NumberConstructor;
    virtual: {
        type: BooleanConstructor;
        default: any;
    };
    direction: {
        type: PropType<any>;
    };
};
export declare type TreeProps = Partial<ExtractPropTypes<ReturnType<typeof treeProps>>>;
declare const _default: import("vue").DefineComponent<{
    showLine: {
        type: BooleanConstructor;
        default: any;
    };
    /** 是否支持多选 */
    multiple: {
        type: BooleanConstructor;
        default: any;
    };
    /** 是否自动展开父节点 */
    autoExpandParent: {
        type: BooleanConstructor;
        default: any;
    };
    /** checkable状态下节点选择完全受控（父子节点选中状态不再关联）*/
    checkStrictly: {
        type: BooleanConstructor;
        default: any;
    };
    /** 是否支持选中 */
    checkable: {
        type: BooleanConstructor;
        default: any;
    };
    /** 是否禁用树 */
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    /** 默认展开所有树节点 */
    defaultExpandAll: {
        type: BooleanConstructor;
        default: any;
    };
    /** 默认展开对应树节点 */
    defaultExpandParent: {
        type: BooleanConstructor;
        default: any;
    };
    /** 默认展开指定的树节点 */
    defaultExpandedKeys: {
        type: PropType<any[]>;
    };
    /** （受控）展开指定的树节点 */
    expandedKeys: {
        type: PropType<any[]>;
    };
    /** （受控）选中复选框的树节点 */
    checkedKeys: {
        type: PropType<any[] | {
            checked: any[];
            halfChecked: any[];
        }>;
    };
    /** 默认选中复选框的树节点 */
    defaultCheckedKeys: {
        type: PropType<any[]>;
    };
    /** （受控）设置选中的树节点 */
    selectedKeys: {
        type: PropType<any[]>;
    };
    /** 默认选中的树节点 */
    defaultSelectedKeys: {
        type: PropType<any[]>;
    };
    selectable: {
        type: BooleanConstructor;
        default: any;
    };
    loadedKeys: {
        type: PropType<any[]>;
    };
    draggable: {
        type: BooleanConstructor;
        default: any;
    };
    showIcon: {
        type: BooleanConstructor;
        default: any;
    };
    icon: {
        type: PropType<(nodeProps: AntdTreeNodeAttribute) => any>;
    };
    switcherIcon: import("vue-types").VueTypeValidableDef<any>;
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    /**
     * @default{title,key,children}
     * deprecated, please use `fieldNames` instead
     * 替换treeNode中 title,key,children字段为treeData中对应的字段
     */
    replaceFields: {
        type: PropType<any>;
    };
    blockNode: {
        type: BooleanConstructor;
        default: any;
    };
    openAnimation: import("vue-types").VueTypeValidableDef<any>;
    focusable: {
        type: BooleanConstructor;
        default: any;
    };
    tabindex: NumberConstructor;
    children: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    treeData: {
        type: PropType<any[]>;
    };
    fieldNames: {
        type: PropType<any>;
    };
    allowDrop: {
        type: PropType<import("../vc-tree/props").AllowDrop>;
    };
    dropIndicatorRender: {
        type: PropType<(props: {
            dropPosition: 0 | 1 | -1;
            dropLevelOffset: number;
            indent: number;
            prefixCls: string;
            direction: any;
        }) => any>;
    };
    onFocus: {
        type: PropType<(e: FocusEvent) => void>;
    };
    onBlur: {
        type: PropType<(e: FocusEvent) => void>;
    };
    onKeydown: {
        type: PropType<import("../_util/EventInterface").EventHandler>;
    };
    onContextmenu: {
        type: PropType<import("../_util/EventInterface").EventHandler>;
    };
    onClick: {
        type: PropType<import("../vc-tree/contextTypes").NodeMouseEventHandler>;
    };
    onDblclick: {
        type: PropType<import("../vc-tree/contextTypes").NodeMouseEventHandler>;
    };
    onScroll: {
        type: PropType<import("../_util/EventInterface").EventHandler>;
    };
    onExpand: {
        type: PropType<(expandedKeys: any[], info: {
            node: any;
            expanded: boolean;
            nativeEvent: MouseEvent;
        }) => void>;
    };
    onCheck: {
        type: PropType<(checked: any[] | {
            checked: any[];
            halfChecked: any[];
        }, info: import("../vc-tree/props").CheckInfo) => void>;
    };
    onSelect: {
        type: PropType<(selectedKeys: any[], info: {
            event: "select";
            selected: boolean;
            node: any;
            selectedNodes: any[];
            nativeEvent: MouseEvent;
        }) => void>;
    };
    onLoad: {
        type: PropType<(loadedKeys: any[], info: {
            event: "load";
            node: any;
        }) => void>;
    };
    loadData: {
        type: PropType<(treeNode: any) => Promise<void>>;
    };
    onMouseenter: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeMouseEventParams) => void>;
    };
    onMouseleave: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeMouseEventParams) => void>;
    };
    onRightClick: {
        type: PropType<(info: {
            event: MouseEvent;
            node: any;
        }) => void>;
    };
    onDragstart: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeDragEventParams) => void>;
    };
    onDragenter: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeDragEventParams & {
            expandedKeys: any[];
        }) => void>;
    };
    onDragover: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeDragEventParams) => void>;
    };
    onDragleave: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeDragEventParams) => void>;
    };
    onDragend: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeDragEventParams) => void>;
    };
    onDrop: {
        type: PropType<(info: import("../vc-tree/contextTypes").NodeDragEventParams & {
            dragNode: any;
            dragNodesKeys: any[];
            dropPosition: number;
            dropToGap: boolean;
        }) => void>;
    };
    onActiveChange: {
        type: PropType<(key: any) => void>;
    };
    filterTreeNode: {
        type: PropType<(treeNode: any) => boolean>;
    };
    motion: import("vue-types").VueTypeValidableDef<any>;
    height: NumberConstructor;
    itemHeight: NumberConstructor;
    virtual: {
        type: BooleanConstructor;
        default: any;
    };
    direction: {
        type: PropType<any>;
    };
}, () => JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, ("select" | "dblclick" | "update:selectedKeys" | "check" | "doubleclick" | "update:checkedKeys" | "update:expandedKeys" | "expand")[], "select" | "dblclick" | "update:selectedKeys" | "check" | "doubleclick" | "update:checkedKeys" | "update:expandedKeys" | "expand", import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    showLine?: unknown;
    multiple?: unknown;
    autoExpandParent?: unknown;
    checkStrictly?: unknown;
    checkable?: unknown;
    disabled?: unknown;
    defaultExpandAll?: unknown;
    defaultExpandParent?: unknown;
    defaultExpandedKeys?: unknown;
    expandedKeys?: unknown;
    checkedKeys?: unknown;
    defaultCheckedKeys?: unknown;
    selectedKeys?: unknown;
    defaultSelectedKeys?: unknown;
    selectable?: unknown;
    loadedKeys?: unknown;
    draggable?: unknown;
    showIcon?: unknown;
    icon?: unknown;
    switcherIcon?: unknown;
    prefixCls?: unknown;
    replaceFields?: unknown;
    blockNode?: unknown;
    openAnimation?: unknown;
    focusable?: unknown;
    tabindex?: unknown;
    children?: unknown;
    treeData?: unknown;
    fieldNames?: unknown;
    allowDrop?: unknown;
    dropIndicatorRender?: unknown;
    onFocus?: unknown;
    onBlur?: unknown;
    onKeydown?: unknown;
    onContextmenu?: unknown;
    onClick?: unknown;
    onDblclick?: unknown;
    onScroll?: unknown;
    onExpand?: unknown;
    onCheck?: unknown;
    onSelect?: unknown;
    onLoad?: unknown;
    loadData?: unknown;
    onMouseenter?: unknown;
    onMouseleave?: unknown;
    onRightClick?: unknown;
    onDragstart?: unknown;
    onDragenter?: unknown;
    onDragover?: unknown;
    onDragleave?: unknown;
    onDragend?: unknown;
    onDrop?: unknown;
    onActiveChange?: unknown;
    filterTreeNode?: unknown;
    motion?: unknown;
    height?: unknown;
    itemHeight?: unknown;
    virtual?: unknown;
    direction?: unknown;
} & {
    prefixCls: string;
} & {
    disabled?: boolean;
    children?: import("../_util/type").VueNode;
    icon?: (nodeProps: AntdTreeNodeAttribute) => any;
    multiple?: boolean;
    onDragend?: (info: import("../vc-tree/contextTypes").NodeDragEventParams) => void;
    onDragenter?: (info: import("../vc-tree/contextTypes").NodeDragEventParams & {
        expandedKeys: any[];
    }) => void;
    onDragleave?: (info: import("../vc-tree/contextTypes").NodeDragEventParams) => void;
    onDragover?: (info: import("../vc-tree/contextTypes").NodeDragEventParams) => void;
    onDragstart?: (info: import("../vc-tree/contextTypes").NodeDragEventParams) => void;
    onDrop?: (info: import("../vc-tree/contextTypes").NodeDragEventParams & {
        dragNode: any;
        dragNodesKeys: any[];
        dropPosition: number;
        dropToGap: boolean;
    }) => void;
    onFocus?: (e: FocusEvent) => void;
    onBlur?: (e: FocusEvent) => void;
    onLoad?: (loadedKeys: any[], info: {
        event: "load";
        node: any;
    }) => void;
    onKeydown?: import("../_util/EventInterface").EventHandler;
    onClick?: import("../vc-tree/contextTypes").NodeMouseEventHandler;
    onContextmenu?: import("../_util/EventInterface").EventHandler;
    onDblclick?: import("../vc-tree/contextTypes").NodeMouseEventHandler;
    onMouseenter?: (info: import("../vc-tree/contextTypes").NodeMouseEventParams) => void;
    onMouseleave?: (info: import("../vc-tree/contextTypes").NodeMouseEventParams) => void;
    onSelect?: (selectedKeys: any[], info: {
        event: "select";
        selected: boolean;
        node: any;
        selectedNodes: any[];
        nativeEvent: MouseEvent;
    }) => void;
    onScroll?: import("../_util/EventInterface").EventHandler;
    height?: number;
    showIcon?: boolean;
    direction?: unknown;
    draggable?: boolean;
    tabindex?: number;
    loadData?: (treeNode: any) => Promise<void>;
    fieldNames?: unknown;
    openAnimation?: any;
    virtual?: boolean;
    motion?: any;
    selectable?: boolean;
    onExpand?: (expandedKeys: any[], info: {
        node: any;
        expanded: boolean;
        nativeEvent: MouseEvent;
    }) => void;
    selectedKeys?: any[];
    checkedKeys?: any[] | {
        checked: any[];
        halfChecked: any[];
    };
    checkable?: boolean;
    switcherIcon?: any;
    focusable?: boolean;
    expandedKeys?: any[];
    loadedKeys?: any[];
    itemHeight?: number;
    onActiveChange?: (key: any) => void;
    treeData?: any[];
    showLine?: boolean;
    checkStrictly?: boolean;
    defaultExpandParent?: boolean;
    autoExpandParent?: boolean;
    defaultExpandAll?: boolean;
    defaultExpandedKeys?: any[];
    defaultCheckedKeys?: any[];
    defaultSelectedKeys?: any[];
    allowDrop?: import("../vc-tree/props").AllowDrop;
    dropIndicatorRender?: (props: {
        dropPosition: 0 | 1 | -1;
        dropLevelOffset: number;
        indent: number;
        prefixCls: string;
        direction: any;
    }) => any;
    onCheck?: (checked: any[] | {
        checked: any[];
        halfChecked: any[];
    }, info: import("../vc-tree/props").CheckInfo) => void;
    onRightClick?: (info: {
        event: MouseEvent;
        node: any;
    }) => void;
    filterTreeNode?: (treeNode: any) => boolean;
    blockNode?: boolean;
    replaceFields?: unknown;
}> & {
    onDblclick?: (...args: any[]) => any;
    onSelect?: (...args: any[]) => any;
    onExpand?: (...args: any[]) => any;
    "onUpdate:selectedKeys"?: (...args: any[]) => any;
    onCheck?: (...args: any[]) => any;
    onDoubleclick?: (...args: any[]) => any;
    "onUpdate:checkedKeys"?: (...args: any[]) => any;
    "onUpdate:expandedKeys"?: (...args: any[]) => any;
}, {
    disabled: boolean;
    multiple: boolean;
    prefixCls: string;
    showIcon: boolean;
    draggable: boolean;
    virtual: boolean;
    selectable: boolean;
    checkable: boolean;
    focusable: boolean;
    showLine: boolean;
    checkStrictly: boolean;
    defaultExpandParent: boolean;
    autoExpandParent: boolean;
    defaultExpandAll: boolean;
    blockNode: boolean;
}>;
export default _default;
